class ApiUrls:
    url_base = "https://api-key.fusionbrain.ai/key/api/v1/"

    url_text2image_run = f"{url_base}text2image/run"
    url_text2_image_status = f"{url_base}text2image/status/$uuid"


class WebUrls:
    url_base = "https://api.fusionbrain.ai/web/api/v1/"

    url_text2image_run = f"{url_base}text2image/run"
    url_text2_image_status = f"{url_base}text2image/status/$uuid"
